==> cpg1.4.x_plugin_slider_v2.16.zip: slider/lang/spanish.php <==
<?php
/**************************************************
  Coppermine 1.4.x Plugin - Slider $VERSION$=2.15
  *************************************************
  Copyright (c) 2008 Timos-Welt (www.timos-welt.de)
  *************************************************
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  ***************************************************
  Based on a mod by pbasmo, you can find it in this thread:
  http://coppermine-gallery.net/forum/index.php?topic=41197.0
  ***************************************************/

if (!defined('IN_COPPERMINE')) { die('Not in Coppermine...'); }
//language variables
$lang_plugin_slider = array(
'slider_speed'  => 'Velocidad del deslizador',
'slider_height' => 'Altura del deslizador',
'slider_width'  => 'Ancho del deslizador',
'slider_numberofpics' => 'Numero de imagenes',
'slider_bgcolor' => 'Color de fondo (vacio = transparente)',
'display_name' => 'PlugIn Deslizador',
'main_title' => 'Slider PlugIn',
'version' => 'v2.15',
'pluginmanager' => 'Administrador de Plugins',
'slider_install' => 'Instalacion del Deslizador',
'install_button' => 'Instalar Ahora',
'cancel_button' => 'Cancelar',
'slider_yes' => 'Si',
'slider_no' => 'No',
'submit_button' => 'Enviar',
'update_success' => 'Valores actualizados correctamente.',
'album' => 'Album del deslizador',
'skipportrait' => 'Evitar imagenes verticales',
'align' => 'Alineacion del deslizador',
'left' => 'izquierda',
'right' => 'derecha',
'center' => 'centro',
'useenlarge' => 'Use EnlargeIt!',
'enlani' => 'EnlargeIt! animation',
'noani' => 'none',
'fade' => 'Fade in/out',
'glide' => 'Glide',
'enlspeed' => 'EnlargeIt! speed',
'enlmaxstep' => 'EnlargeIt! animation steps',
'enlborder' => 'EnlargeIt! use border',
'enlbrdcolor' => 'EnlargeIt! border color',
'enlbrdsize' => 'EnlargeIt! border thickness',
'enlshowcap' => 'Show pic title as caption',
'pictype' => 'Enlarge to',
'slider_normalsize' => 'intermediate size pic',
'slider_fullsize' => 'full size pic',
'enlbrdshadow' => 'Show border shadow',
'enlshadowsize' => 'Size of shadow right/bottom',
'enlshadowintens' => 'Intensity of shadow',
'slider_autowidth' => 'Auto fit slider width',
'bumpglide' => 'Bump-Glide',
'enlclosebtn' => 'EnlargeIt! use close button',
'enlcenter' => 'EnlargeIt! center enlarged pic in browser window',
'enldark' => 'EnlargeIt! darken screen when pic is enlarged',
);
?>

==> cpg1.5.x_plugin_slider_v0.7.zip: slider/lang/spanish.php <==
<?php
/**************************************************
  Coppermine 1.5.x Plugin - Slider
  *************************************************
  Copyright (c) 2010 Timos-Welt (www.timos-welt.de)
  *************************************************
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.
  ********************************************
  $HeadURL: https://coppermine.svn.sourceforge.net/svnroot/coppermine/branches/cpg1.5.x/plugins/slider/lang/spanish.php $
  $Revision: 6989 $
  $LastChangedBy: timoswelt $
  $Date: 2010-01-03 14:03:16 +0100 (So, 03 Jan 2010) $
  **************************************************/

if (!defined('IN_COPPERMINE')) { die('Not in Coppermine...'); }
//language variables
$lang_plugin_slider = array(
'slider_speed'  => 'Velocidad del deslizador',
'slider_height' => 'Altura del deslizador',
'slider_width'  => 'Ancho del deslizador',
'slider_numberofpics' => 'Numero de imagenes',
'slider_bgcolor' => 'Color de fondo (vacio = transparente)',
'display_name' => 'PlugIn Deslizador',
'main_title' => 'Slider PlugIn',
'version' => '0.5',
'pluginmanager' => 'Administrador de Plugins',
'slider_install' => 'Instalacion del Deslizador',
'install_button' => 'Instalar Ahora',
'cancel_button' => 'Cancelar',
'slider_yes' => 'Si',
'slider_no' => 'No',
'submit_button' => 'Enviar',
'update_success' => 'Valores actualizados correctamente.',
'album' => 'Album del deslizador',
'skipportrait' => 'Evitar imagenes verticales',
'align' => 'Alineacion del deslizador',
'left' => 'izquierda',
'right' => 'derecha',
'center' => 'centro',
'useenlarge' => 'Use EnlargeIt!',
'pictype' => 'Enlarge to',
'slider_normalsize' => 'intermediate size pic',
'slider_fullsize' => 'full size pic',
'slider_autowidth' => 'Auto fit slider width',
);
?>
